FunctionSet

Struct FunctionSet 

pub struct FunctionSet { /* private fields */ }
Helper for managing groups of functions

Sedona coordinates the assembly of a large number of spatial functions with potentially different sets of dependencies (e.g., geography vs. geometry), multiple implementations, and/or implementations that live in different crates. This structure helps coordinate these implementations.

Implementations

Source

impl FunctionSet

pub fn new() -> Self

Create a new, empty FunctionSet

pub fn scalar_udfs(&self) -> impl Iterator<Item = &SedonaScalarUDF> + '_

Iterate over references to all SedonaScalarUDFs

pub fn scalar_udf(&self, name: &str) -> Option<&SedonaScalarUDF>

Return a reference to the function corresponding to the name

pub fn scalar_udf_mut(&mut self, name: &str) -> Option<&mut SedonaScalarUDF>

Return a mutable reference to the function corresponding to the name

pub fn insert_scalar_udf( &mut self, udf: SedonaScalarUDF, ) -> Option<SedonaScalarUDF>

Insert a new ScalarUDF and return the UDF that had previously been added, if any

pub fn aggregate_udfs(&self) -> impl Iterator<Item = &SedonaAggregateUDF> + '_

Iterate over references to all SedonaAggregateUDFs

pub fn aggregate_udf(&self, name: &str) -> Option<&SedonaAggregateUDF>

Return a reference to the aggregate function corresponding to the name

pub fn aggregate_udf_mut( &mut self, name: &str, ) -> Option<&mut SedonaAggregateUDF>

Return a mutable reference to the aggregate function corresponding to the name

pub fn insert_aggregate_udf( &mut self, udf: SedonaAggregateUDF, ) -> Option<SedonaAggregateUDF>

Insert a new AggregateUDF and return the UDF that had previously been added, if any

pub fn merge(&mut self, other: FunctionSet)

Consume another function set and merge its contents into this one

pub fn add_scalar_udf_impl( &mut self, name: &str, kernels: impl IntoScalarKernelRefs, ) -> Result<&SedonaScalarUDF>

Add a kernel to a function in this set

This adds a scalar UDF with immutable output if a function of that name does not exist in this set. A reference to the matching or inserted function is returned.

pub fn add_aggregate_udf_kernel( &mut self, name: &str, kernel: impl IntoSedonaAccumulatorRefs, ) -> Result<&SedonaAggregateUDF>

Add an aggregate kernel to a function in this set

This adds an aggregate UDF with immutable output if a function of that name does not exist in this set. A reference to the matching or inserted function is returned.