pub struct ItemCrsKernel { /* private fields */ }Expand description
Wrap a SedonaScalarKernel to provide Item CRS type support
Most kernels that operate on geometry or geography in some way can also support Item CRS inputs:
- Functions that return a non-spatial type whose value does not
depend on the input CRS only need to operate on the
itemportion of any item_crs input (e.g., ST_Area()). - Functions that accept two or more spatial arguments must have compatible CRSes.
- Functions that return a geometry or geography must also return an item_crs type where the output CRSes are propagated from the input.
This kernel provides an automatic wrapper enforcing these rules. It is appropriate for most functions except:
- Functions whose return value depends on the CRS
- Functions whose return value depends on the value of a scalar argument
- Functions whose return CRS is not strictly propagated from the CRSes of the arguments.
Implementations
Sourceimpl ItemCrsKernel
impl ItemCrsKernel
Sourcepub fn new_ref(inner: ScalarKernelRef) -> ScalarKernelRef
pub fn new_ref(inner: ScalarKernelRef) -> ScalarKernelRef
Create a new ScalarKernelRef wrapping the input
The resulting kernel matches arguments of the input with ItemCrs inputs but not those of the original kernel (i.e., a function needs both kernels to support both type-level and item-level CRSes).
Sourcepub fn wrap_impl(inner: impl IntoScalarKernelRefs) -> Vec<ScalarKernelRef> ⓘ
pub fn wrap_impl(inner: impl IntoScalarKernelRefs) -> Vec<ScalarKernelRef> ⓘ
Wrap a vector of kernels by appending all ItemCrs versions followed by the contents of inner
This is the recommended way to add kernels when all of them should support ItemCrs inputs.