pub struct SedonaAggregateUDF { /* private fields */ }Expand description
Top-level aggregate user-defined function
This struct implements datafusion’s AggregateUDFImpl and implements kernel dispatch such that implementations can be registered flexibly.
Implementations
Sourceimpl SedonaAggregateUDF
impl SedonaAggregateUDF
Sourcepub fn new(
name: &str,
kernels: impl IntoSedonaAccumulatorRefs,
volatility: Volatility,
) -> Self
pub fn new( name: &str, kernels: impl IntoSedonaAccumulatorRefs, volatility: Volatility, ) -> Self
Create a new SedonaAggregateUDF
Sourcepub fn from_impl(name: &str, kernels: impl IntoSedonaAccumulatorRefs) -> Self
pub fn from_impl(name: &str, kernels: impl IntoSedonaAccumulatorRefs) -> Self
Create a new immutable SedonaAggregateUDF
Sourcepub fn add_kernel(&mut self, kernels: impl IntoSedonaAccumulatorRefs)
pub fn add_kernel(&mut self, kernels: impl IntoSedonaAccumulatorRefs)
Add a new kernel to an Aggregate UDF
Because kernels are resolved in reverse order, the new kernel will take precedence over any previously added kernels that apply to the same types.
pub fn kernels(&self) -> &[SedonaAccumulatorRef] ⓘ