pub struct SedonaAggregateUDF { /* private fields */ }Expand description
Top-level aggregate user-defined function
This struct implements datafusion’s AggregateUDFImpl and implements kernel dispatch such that implementations can be registered flexibly.
Implementations
Sourceimpl SedonaAggregateUDF
impl SedonaAggregateUDF
Sourcepub fn new(
name: &str,
kernels: Vec<SedonaAccumulatorRef>,
volatility: Volatility,
documentation: Option<Documentation>,
) -> Self
pub fn new( name: &str, kernels: Vec<SedonaAccumulatorRef>, volatility: Volatility, documentation: Option<Documentation>, ) -> Self
Create a new SedonaAggregateUDF
Sourcepub fn new_stub(
name: &str,
arg_matcher: ArgMatcher,
volatility: Volatility,
documentation: Option<Documentation>,
) -> Self
pub fn new_stub( name: &str, arg_matcher: ArgMatcher, volatility: Volatility, documentation: Option<Documentation>, ) -> Self
Create a new stub aggregate function
Creates a new aggregate function that calculates a return type but fails when invoked with arguments. This is useful to create stub functions when it is expected that the actual functionality will be registered from one or more independent crates (e.g., ST_Union_Agg(), which may be implemented in sedona-geo or sedona-geography).
Sourcepub fn add_kernel(&mut self, kernel: SedonaAccumulatorRef)
pub fn add_kernel(&mut self, kernel: SedonaAccumulatorRef)
Add a new kernel to an Aggregate UDF
Because kernels are resolved in reverse order, the new kernel will take precedence over any previously added kernels that apply to the same types.
pub fn kernels(&self) -> &[SedonaAccumulatorRef] ⓘ