TableGeoStatistics

Enum TableGeoStatistics 

pub enum TableGeoStatistics {
    ByPosition(Vec<GeoStatistics>),
    ByName(HashMap<String, GeoStatistics>),
}
Table GeoStatistics

Enables providing a collection of GeoStatistics to SpatialFilter::evaluate such that attempts to access out-of-bounds values results in a readable error.

Variants



ByPosition(Vec<GeoStatistics>)

Provide statistics for every Column in the table. These must be GeoStatistics::unspecified for non-spatial columns.

These are resolved using Column::index.



ByName(HashMap<String, GeoStatistics>)

Provide statistics for specific named columns. Columns not included are treated as GeoStatistics::unspecified.

These are resolved using Column::name. This may be used for logical expressions (where columns are resolved by name) or as a workaround for physical expressions where the index is relative to a projected schema https://github.com/apache/sedona-db/issues/389.

Implementations

Source

impl TableGeoStatistics

pub fn empty() -> Self

Construct TableGeoStatistics with no columns

pub fn try_from_stats_and_schema( column_stats: &[GeoStatistics], schema: &Schema, ) -> Result<Self>

Construct TableGeoStatistics from a slice of all column statistics and a schema